"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getChunks = void 0;
const mergeEntries_1 = require("./mergeEntries");
const convertEntriesToChunks_1 = require("./convertEntriesToChunks");
const getEntries_1 = require("./getEntries");
const getRegExpFlags_1 = require("./getRegExpFlags");
/**
 * returns array of chunks that represents highlighted and non highlighted text pieces
 */
function getChunks({ text, substrings, caseSensitive = false, sanitize, }) {
    const truthySubstrings = substrings.filter(Boolean);
    if (!text || truthySubstrings.length === 0) {
        return [
            {
                text,
                highlighted: false,
            },
        ];
    }
    const sanitizedText = sanitize ? sanitize(text) : text;
    const sanitizedSubstrings = sanitize
        ? truthySubstrings.map((substring) => sanitize(substring))
        : truthySubstrings;
    const entries = (0, getEntries_1.getEntries)(sanitizedText, sanitizedSubstrings, (0, getRegExpFlags_1.getRegExpFlags)(caseSensitive));
    if (entries.length === 0) {
        return [
            {
                text: sanitizedText,
                highlighted: false,
            },
        ];
    }
    const concatenatedEntries = (0, mergeEntries_1.mergeEntries)(entries);
    const chunks = (0, convertEntriesToChunks_1.convertEntriesToChunks)(concatenatedEntries, sanitizedText);
    return chunks;
}
exports.getChunks = getChunks;
